@@ -1,13 +1,10 @@
 /******************************************************************************
 *   KBlocks, a falling blocks game by KDE                                     *
-*   Copyright (C) 2009-2021 Mauricio Piacentini <mauricio@tabuleiro.com>      *
+*   SPDX-FileCopyrightText: 2009-2021 Mauricio Piacentini <mauricio@tabuleiro.com>      *
 *                           Zhongjie Cai <squall.leonhart.cai@gmail.com>      *
 *                           Julian Helfferich <julian.helfferich@mailbox.org> *
 *                                                                             *
-*   This program is free software; you can redistribute it and/or modify      *
-*   it under the terms of the GNU General Public License as published by      *
-*   the Free Software Foundation; either version 2 of the License, or         *
-*   (at your option) any later version.                                       *
+*   SPDX-License-Identifier: GPL-2.0-or-later
 ******************************************************************************/
 #include <ctime>
 #include <string>
@@ -23,7 +20,9 @@
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QCommandLineOption>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <Kdelibs4ConfigMigrator>
+#endif
 using namespace std;
 
 #include "KBlocksConfigManager.h"
@@ -339,13 +338,16 @@ int gamePlayerMode(KBlocksConfigManager *config, const QApplication &app)
 int main(int argc, char *argv[])
 {
     // Fixes blurry icons with fractional scaling
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+#endif
     QApplication app(argc, argv);
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Kdelibs4ConfigMigrator migrate(QStringLiteral("kblocks"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("kblocksrc"));
     migrate.setUiFiles(QStringList() << QStringLiteral("kblocksui.rc"));
     migrate.migrate();
+#endif
     KLocalizedString::setApplicationDomain("kblocks");
     // Game abouts...
 
